@@ -35,6 +35,7 @@ class MsgFields(ConstantDict):
     ASNIP = "asnip"
     ASN = "asn"
     AS_NAME = "asname"
+    AS_CIDR = "ascidr"
     ARTIFACT = "artifact"
     CIDR = "cidr"
     COUNTRY_CODE = "cc"
@@ -46,6 +47,9 @@ class MsgFields(ConstantDict):
     HTTP_STATUS = "httpstatus"
     IP = "ip"
     IPSET = "ipset"
+    NET_CIDR = "cidr"
+    NET_DESC = "netdesc"
+    NET_NAME = "netcidr"
     PATH = "path"
     SCREENSHOT = "screenshot"
     SPIDER = "spider"
